==> java-cxf-spring-server-generator-0.13.2.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/CreateTransactionResponse.java <==
package com.example.model;

/**
 * Model for Create
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-05T19:55:16.329Z")
@io.swagger.annotations.ApiModel(value = "CreateTransactionResponse", description = "Model for Create")
@javax.xml.bind.annotation.XmlRootElement(name = "CreateTransactionResponse")
public class CreateTransactionResponse implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String transactionId = null;
	private java.lang.String url = null;
	
	/**
	 */
	public CreateTransactionResponse transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(required = true, value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	@javax.validation.constraints.NotNull
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	/**
	 */
	public CreateTransactionResponse url(java.lang.String url) {
		setUrl(url);
		return this;
	}
	
	@io.swagger.annotations.ApiModelProperty(value = "")
	@com.fasterxml.jackson.annotation.JsonProperty("url")
	public java.lang.String getUrl() {
		return this.url;
	}
	public void setUrl(java.lang.String url) {
		this.url = url;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		CreateTransactionResponse createTransactionResponse = (CreateTransactionResponse) o;
		return java.util.Objects.equals(this.transactionId, createTransactionResponse.transactionId)
				&& java.util.Objects.equals(this.url, createTransactionResponse.url);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.transactionId, this.url);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class CreateTransactionResponse {\n");
		
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}

==> java-cxf-spring-server-generator-0.14.0.tgz: package/test-output/junit5/idkit_v1-openapi_spec.yml/src/main/java/com/example/model/CreateTransactionResponse.java <==
package com.example.model;

/**
 * Model for Create
 */
@javax.annotation.Generated(value = "@openapi-generator-plus/java-cxf-spring-server-generator", date = "2021-04-09T22:14:49.443Z")
@io.swagger.v3.oas.annotations.media.Schema(name = "CreateTransactionResponse", description = "Model for Create")
@javax.xml.bind.annotation.XmlRootElement(name = "CreateTransactionResponse")
public class CreateTransactionResponse implements java.io.Serializable {

	private static final long serialVersionUID = 1L;
	private java.lang.String transactionId = null;
	private java.lang.String url = null;
	
	/**
	 */
	public CreateTransactionResponse transactionId(java.lang.String transactionId) {
		setTransactionId(transactionId);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(required = true, name = "transaction_id")
	@com.fasterxml.jackson.annotation.JsonProperty("transaction_id")
	@javax.validation.constraints.NotNull
	public java.lang.String getTransactionId() {
		return this.transactionId;
	}
	public void setTransactionId(java.lang.String transactionId) {
		this.transactionId = transactionId;
	}
	
	/**
	 */
	public CreateTransactionResponse url(java.lang.String url) {
		setUrl(url);
		return this;
	}
	
	@io.swagger.v3.oas.annotations.media.Schema(name = "url")
	@com.fasterxml.jackson.annotation.JsonProperty("url")
	public java.lang.String getUrl() {
		return this.url;
	}
	public void setUrl(java.lang.String url) {
		this.url = url;
	}
	
	@Override
	public boolean equals(java.lang.Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		CreateTransactionResponse createTransactionResponse = (CreateTransactionResponse) o;
		return java.util.Objects.equals(this.transactionId, createTransactionResponse.transactionId)
				&& java.util.Objects.equals(this.url, createTransactionResponse.url);
	}
	
	@Override
	public int hashCode() {
		return java.util.Objects.hash(this.transactionId, this.url);
	}
	
	@Override
	public String toString() {
		StringBuilder sb = new StringBuilder();
		sb.append("class CreateTransactionResponse {\n");
		
		sb.append("    transactionId: ").append(toIndentedString(this.transactionId)).append("\n");
		sb.append("    url: ").append(toIndentedString(this.url)).append("\n");
		sb.append("}");
		return sb.toString();
	}
	
	/**
	 * Convert the given object to string with each line indented by 4 spaces
	 * (except the first line).
	 */
	private String toIndentedString(java.lang.Object o) {
		if (o == null) {
			return "null";
		}
		return o.toString().replace("\n", "\n    ");
	}
	
}
